@@ -26,6 +26,39 @@ Champlain - Map rendering canvas
 	# Main loop
 	Clutter->main();
 
+=head1 ABSTRACT
+
+B<DEPRECATED> Perl bindings for the C library 'libchamplain-gtk'
+
+=head1 DESCRIPTION
+
+B<NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE NOTICE>
+
+This module has been deprecated by the Gtk-Perl project.  This means that the
+module will no longer be updated with security patches, bug fixes, or when
+changes are made in the Perl ABI.  The Git repo for this module has been
+archived (made read-only), it will no longer possible to submit new commits to
+it.  You are more than welcome to ask about this module on the Gtk-Perl
+mailing list, but our priorities going forward will be maintaining Gtk-Perl
+modules that are supported and maintained upstream; this module is neither.
+
+Since this module is licensed under the LGPL v2.1, you may also fork this
+module, if you wish, but you will need to use a different name for it on CPAN,
+and the Gtk-Perl team requests that you use your own resources (mailing list,
+Git repos, bug trackers, etc.) to maintain your fork going forward.
+
+=over
+
+=item *
+
+Perl URL: https://gitlab.gnome.org/GNOME/perl-champlain
+
+=item *
+
+Upstream URL: https://gitlab.gnome.org/GNOME/libchamplain
+
+=back
+
 =head1 DESCRIPTION
 
 Champlain consists of the Perl bindings for the C library libchamplain which
@@ -119,7 +152,7 @@ For the terms of The Artistic License, see L<perlartistic>.
 use warnings;
 use strict;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use base 'DynaLoader';
 use Exporter 'import';
